lcvtoolbox.integrations.huggingface.image\_classification.ImageClassificationDatasetProcessor
=============================================================================================

.. currentmodule:: lcvtoolbox.integrations.huggingface.image_classification

.. autoclass:: ImageClassificationDatasetProcessor
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ImageClassificationDatasetProcessor.__init__
      ~ImageClassificationDatasetProcessor.add_image
      ~ImageClassificationDatasetProcessor.add_images
      ~ImageClassificationDatasetProcessor.create_streaming_dataset
      ~ImageClassificationDatasetProcessor.flush_all_batches
      ~ImageClassificationDatasetProcessor.get_dataset_info
      ~ImageClassificationDatasetProcessor.initialize_dataset
      ~ImageClassificationDatasetProcessor.load_dataset_from_hub
      ~ImageClassificationDatasetProcessor.reset_dataset
      ~ImageClassificationDatasetProcessor.save_dataset_locally
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ImageClassificationDatasetProcessor.dataset_name
      ~ImageClassificationDatasetProcessor.labels
   
   